#include <gccore.h> 

#include "defines.h"
#include "globals.h"

int timing[]={30,27,24,21,18,15,12,9,6,3};

// Fills the player block structure with information
// about the current block.
void FillBlockInfo(cblock& p)
{
	cblockdesc& desc = blocks[p.blocknum];

	for(int y = 0; y < 4; y++)
	{
		for(int x = 0; x < 4; x++)
		{
			p.map[x][y] = desc.map[p.rot][x][y];
		}
	}

	p.xstart = desc.xstart[p.rot];
	p.ystart = desc.ystart[p.rot];

	p.xend = desc.xend[p.rot];
	p.yend = desc.yend[p.rot];
}

// Randomly selects a new block and updates the block
// object.
void NewBlock(int player)
{
	cblock& p = block[player];

	p.blocknum=(int)(genrand()*NUMTYPES);

	p.gfx=(int)(genrand()*7);

	p.xtile = 3;
	p.ytile = -1;

	p.rot = 0;

	FillBlockInfo(p);
}

void DrawMap(int player)
{
	for(int y = 0; y < 20; y++)
	{
		for(int x = 0; x < 10; x++)
		{
			u8 gfx = map[player][x][y];

			if(gfx != 9)
				DrawSquare(x, y, gfx, player);
		}
	}
}

// Draw the current block inside the play field
void DrawBlock(int player)
{
	cblock& p = block[player];
	cblockdesc& desc = blocks[p.blocknum];

	for(int y = 0; y < 4; y++)
	{
		for(int x = 0; x < 4; x++)
		{
			int calcx = x + p.xtile;
			int calcy = y + p.ytile;

			if(desc.map[p.rot][x][y] == 1 && calcx >= 0 && calcy >= 0)
				DrawSquare(calcx, calcy, p.gfx, player);
		}
	}
}

void DrawSquare(int x,int y,u8 gfx,int player)
{
	if(y < 0)
		return;

	if(options.players==1 && options.netplay==0)
	{
		x+=11;
		y+=2;
	}
	else
	{
		x+=3+player*16;
		y+=2;
	}


	for(int newy = 0; newy < 20; newy++)
	{
		for(int newx = 0; newx < 10; newx++)
			xfb[newx + x * 10 + (newy + y * 20) * 320] = blockgfx[gfx][newx + newy * 10];
	}
}
